<?php
/**
 * @package   Set Filters
 * @version   1.0.1
 * @author    Randy Carey
 * link       http://iCueProject.com
 * @copyright Copyright (C) 2014 Randy Carey, iCue Project
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

// no direct access
defined('_JEXEC') or die('Restricted index access');

/**
 * Class plgSystemSetfilters
 *
 * This plugin finds filter_ and list_ parameters and sets their value within the session in the array format that the new XML filters expect.
 * This plugin retores the functionality and backwards-compatibility that were lost beginning with Joomla 3.2.0.
 */
class plgSystemSetfilters extends JPlugin {
    private $filter_requests=array();
    private $list_requests=array();


    public function onAfterRoute() {
	   	$app =& JFactory::getApplication();
        if(!($option = $app->input->get('option')) || !($view=$app->input->get('view'))){
            return;
        }
        $this->getFilterRequests($app);
        if(count($this->filter_requests)){
            $this->updateUserSession($app, $option, $view, $this->filter_requests, 'filter');
        }
        if(count($this->list_requests)){
            $this->updateUserSession($app, $option, $view, $this->list_requests, 'list');
        }
   }

    /** Iterate through request and store each filter_ and list_ request that is found.
     *  Storage is in array form.  It is assumed that components not using XML filter fields already handle filter fields
     *
     * @param $app
     * @param &$fitler_request - passed by reference, so the results are put into this object
     * @param &$list_request - passed by reference, so the results are put into this object
     */
    private function getFilterRequests($app)
    {
        $requests = $app->input->getArray();

        foreach ($requests as $name => $val) {
            if (strncmp($name, 'filter_', 7) == 0) {
                $this->filter_requests[substr($name,7)] = $val;
            }
            elseif (strncmp($name, 'list_', 5) == 0) {
                $this->list_requests[substr($name,5)] = $val;
            }
        }
    }

    /** // used to update the session with the users requested values, written in the 3.2 array format.
     * // Handles either filter_ or _list parameters
     * @param $app
     * @param $option
     * @param $view
     * @param $requests
     * @param string $type
     */
    private function updateUserSession($app, $option, $view, $requests, $type = 'filter')
    {
        $qualifier = $option . '.' . $view . '.' . $type;
        $session_items = $app->getUserState($qualifier);
        if(!$session_items){
            $session_items = array();
        }elseif(!is_array($session_items)){ // is this needed?
            $session_items = (array)$session_items;
        }
        foreach ($requests as $name => $val) {
            $session_items[$name] = $val;
        }
        $app->setUserState($qualifier, $session_items);

    }


}